# PYTOHub

PYTOHub is a program that can directly connect to your lego spike prime or mindstorms hub

![alt text](banner.png)

# How to download

How to download PYToHub

**Run this in your terminal (Command prompt)**
```
pip install pytohub
```

# How to run pytohub
There is 2 ways to run pytohub.
**You can directly run it in the terminal**
```
python -m pytohub
```
**OR Run it using a python file**
```py
import pytohub
pytohub.run()
```

# How to setup your lego hub
There is 2 ways to setup your lego hub.

You need to setup your lego hub
**You can directly run it in the terminal**
```
python -m pytohub --download
```
**OR Run it using a python file**
```py
import pytohub
pytohub.download_program()
```